@@ -1,7 +1,7 @@
 pub use creek_core::*;
 
-#[cfg(feature = "decode-wav-only")]
-pub use creek_decode_wav::*;
+#[cfg(feature = "decode")]
+pub use creek_decode_symphonia::*;
 
 #[cfg(feature = "encode-wav")]
 pub use creek_encode_wav::*;
